@@ -1,14 +1,16 @@
 from abc import ABC, abstractmethod
+from typing import Union
 
 from pydantic import BaseModel
 
+from pymbse.query.config.notebook_script_config import GitLabConfig
 from pymbse.query.config.pymbse_config import NotebookScriptConfig
 from pymbse.query.model_api.snapshot.model_snapshot import ModelSnapshot
 
 
 class ModelAPI(BaseModel, ABC):
-    root_model_config: NotebookScriptConfig
-    ip_with_port: str
+    root_model_config: Union[NotebookScriptConfig, GitLabConfig]
+    cache_db_ip_with_port: str
     root_model_metadata_hash: str
     input_parameters: dict
     input_files: dict
